UIKitIconDataIcon class final

A Flutter IconData.

Inheritance

Constructors

UIKitIconDataIcon(IconData icon)
Creates an icon from IconData.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
icon → IconData
The icon glyph.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override